
/**
 * @imports
 */
import Destination from './Destination.js';

/**
 * Scrolls an element to a reference point in the UI.
 */
export default class Scroll extends Destination {

    /**
     * @inheritdoc
     */
    constructor(el, reference, options = {}) {
        super(...arguments);
        var viewport = this.options.scrollAnchor || Scroll.scroller(this.el);
        viewport = viewport === document.body ? window : viewport;
        if (!Scroll.test(viewport)) {
            return;
        }
        this.scrollingFormatted = {from: {}, to: {}, current: {
                from: {}, to: {}, progress: {},
            },
            viewport: viewport,
        };
        // -----------
        var currentScroll = {
            scrollLeft: viewport[viewport === window ? 'pageXOffset' : 'scrollLeft'],
            scrollTop: viewport[viewport === window ? 'pageYOffset' : 'scrollTop'],
        };
        ['x', 'y'].forEach((axis, i) => {
            var axisProp = axis === 'x' ? 'scrollLeft' : 'scrollTop';
            if (axis in this.coords) {
                this.scrollingFormatted.from[axisProp] = 0;
                this.scrollingFormatted.to[axisProp] = this.coords[axis] + currentScroll[axisProp];
                // ----------------
                this.scrollingFormatted.current.from[axisProp] = currentScroll[axisProp];
                this.scrollingFormatted.current.to[axisProp] = this.coords[axis];
                // ----------------
                this.scrollingFormatted.current.progress[axis] = Math.abs(currentScroll[axisProp] / (this.coords[axis] + currentScroll[axisProp]));
            } else {
                this.scrollingFormatted.from[axisProp] = currentScroll[axisProp];
                this.scrollingFormatted.to[axisProp] = currentScroll[axisProp];
                // ----------------
                this.scrollingFormatted.current.from[axisProp] = currentScroll[axisProp];
                this.scrollingFormatted.current.to[axisProp] = currentScroll[axisProp];
                // ----------------
                this.scrollingFormatted.current.progress[axis] = 0;
            }
        });
    }
    
    /**
     * Plays the Scroll.
     * 
     * @param object    timing
     * 
     * @return Promise
     */
    play(timing = {}) {
        console.log('scrollTo() does not currently support animation.');
    }

    /**
     * Sets the Scroll.
     * 
     * @return void
     */
    go() {
		return this.scrollingFormatted.viewport.scrollTo(
            this.scrollingFormatted.to.scrollLeft,
            this.scrollingFormatted.to.scrollTop
        );
    }
   
    /**
     * Tells if an element is scrollable due to overflowing content.
     *
     * @param DOMNode		el
     *
     * @return bool
     */
    static test(el) {
        return el === window 
            ? (el.pageYOffset || el.pageYOffset) 
            : (el.scrollHeight > el.clientHeight);
    }
    
    /**
     * Gets an element's nearest scrollable parent.
     *
     * @param DOMNode		el
     *
     * @return Element
     */
    static scroller(el) {
        var style = window.getComputedStyle(el);
        var excludeStaticParent = style.position === 'absolute';
        var overflowRegex = false/*includeHidden*/ ? /(auto|scroll|hidden)/ : /(auto|scroll)/;
        if (style.position !== 'fixed') {
            for (var parent = el; (parent = parent.parentElement);) {
                style = window.getComputedStyle(parent);
                if (excludeStaticParent && style.position === 'static') {
                    continue;
                }
                if (overflowRegex.test(style.overflow + style.overflowY + style.overflowX)) {
                    return parent;
                }
            }
        }
        return document.body;
    }
};
