
/**
 * @imports
 */
import _isNumeric from '@web-native-js/commons/js/isNumeric.js';
import _merge from '@web-native-js/commons/obj/merge.js';
import Rect from './Rect.js';

/**
 * The Angle class.
 */
export default class Angle extends Rect {

    /**
     * Returns values of the angle between two rects.
     *
    * @param Rect|Element|Event|window 	rect1
    * @param Rect|Element|Event|window 	rect2
     *
     * @return Angle
     */
    static of(rect1, rect2) {
        rect1 = Rect.of(rect1);
        rect2 = Rect.of(rect2);
        var $props = {};
        $props.x = (rect2.left + (rect2.width / 2)) - (rect1.left + (rect1.width / 2));
        $props.y = (rect2.top + (rect2.height / 2)) - (rect1.top + (rect1.height / 2));
        $props.z = Math.sqrt(Math.pow($props.x, 2) + Math.pow($props.y, 2));
        if (_isNumeric($props.y) && _isNumeric($props.x)) {
            $props.angleOfElevation = Math.atan($props.y/$props.x);
        } else if (_isNumeric($props.x) && _isNumeric($props.z)) {
            $props.angleOfElevation = Math.acos($props.x/$props.z);
        } else if (_isNumeric($props.y) && _isNumeric($props.z)) {
            $props.angleOfElevation = Math.asin($props.y/$props.z);
        }
        $props.angleOfDepression = 180 - 90 - $props.angleOfElevation;
        $props.isHorizontal = angleOfElevation < 45;
        $props.isVertical = angleOfDepression < 45;
        return new Angle($props);
    }
};